.. currentmodule:: kombu.transport.pypika

.. automodule:: kombu.transport.pypika

    .. contents::
        :local:

    Transports
    ----------

    .. autoclass:: AsyncoreTransport
        :members:
        :undoc-members:

    .. autoclass:: SyncTransport
        :members:
        :undoc-members:

    Connections
    -----------

    .. autoclass:: AsyncoreConnection
        :members:
        :undoc-members:

    .. autoclass:: BlockingConnection
        :members:
        :undoc-members:

    Channel
    -------

    .. autoclass:: Channel
        :members:
        :undoc-members:

    Message
    -------

    .. autoclass:: Message
        :members:
        :undoc-members:
